---
title: TokenRequest
type: Custom Resource
---

The `tokenrequests.applicationconnector.kyma-project.io` CustomResourceDefinition (CRD) is a detailed description of the kind of data and the format used to request a token for an Application configuration URL from the Connector Service. To get the up-to-date CRD and show the output in the `yaml` format, run this command:

```bash
kubectl get crd tokenrequests.applicationconnector.kyma-project.io -o yaml
```

## Sample custom resource

This is a sample custom resource (CR) which allows to get the configuration required to connect an external solution to the `test` Application.

```yaml
apiVersion: applicationconnector.kyma-project.io/v1alpha1
kind: TokenRequest
metadata:
  name: test-app
context:
  tenant: test-tenant
  group: test-group
```

## Custom resource parameters

This table lists all the possible parameters of a given resource together with their descriptions:

| Parameter   |      Required      |  Description |
|----------|:-------------:|------|
| **metadata.name** | Yes | Specifies the name of the CR and the Application for which to request a token. |
| **context.tenant**| No | Specifies the name of the Tenant.  |
| **context.group** | No | Specifies the name of the Group. |

## Additional information

When you fetch an existing TokenRequest CR, the system adds the **status** section which describes the status of the request and lists the configuration details. This table lists the fields of the **status** section.

| Field   |  Description |
|----------|-------------|
| **status.expireAfter** | Date and time after which the token expires and the controller deletes the CR. |
| **status.application** | The name of the Application for which the token was issued. |
| **status.state** | Status of the token request. This field can have one of the two values: `OK` or `ERR`. |
| **status.token** | The token generated by the Connector Service. |
| **status.url** | The URL to the Connector Service info endpoint with the token. |
