# Migrate from 1.19 to 1.20

## Fluent Bit

Kyma 1.20 comes with a redesigned configuration for Fluent Bit. It is redesigned to be up to date with the upstream chart and also be consistent with the rest of the configuration values. The latest configurations can be found in the [chart](https://github.com/kyma-project/kyma/blob/master/resources/logging/charts/fluent-bit/values.yaml#L134). If you have been using overrides for Fluent Bit, compare them with the latest configurations and adapt if necessary. It also now supports many more configuration options for the plugins coming out of the box. For example, you can set the `alias` field for all the input and output plugins to be used as the parent name for the metric. You can read more about it in this [Fluent Bit manual](https://docs.fluentbit.io/manual/administration/monitoring#configuring-aliases).  

An example migration looks like the following. These are the old overrides:

```yaml
apiVersion: v1
kind: ConfigMap
metadata:
  name: logging-overrides
  namespace: kyma-installer
  labels:
    installer: overrides
    component: logging
    kyma-project.io/installation: ""
data:
  fluent-bit.conf.Output.http.enabled: "true"
  fluent-bit.conf.Output.http.Match : "*"
  fluent-bit.backend.http.host: "<Fluentd-endpoint from service key json>"
  fluent-bit.backend.http.port: "443"
  fluent-bit.backend.http.http_user: "<Fluentd-username from service key json>"
  fluent-bit.backend.http.http_passwd: "<Fluentd-password from service key json>"
  fluent-bit.backend.http.tls: "true"
  fluent-bit.backend.http.tls_verify : "false"
```

These are the new overrides: 

```yaml
apiVersion: v1
kind: ConfigMap
metadata:
  name: logging-overrides
  namespace: kyma-installer
  labels:
    installer: overrides
    component: logging
    kyma-project.io/installation: ""
data:
  fluent-bit.config.outputs.http.enabled: "true"
  fluent-bit.config.outputs.http.match : "*"
  fluent-bit.config.outputs.http.host: "<Fluentd-endpoint from service key json>"
  fluent-bit.config.outputs.http.port: "443"
  fluent-bit.config.outputs.http.httpUser: "<Fluentd-username from service key json>"
  fluent-bit.config.outputs.http.httpPasswd: "<Fluentd-password from service key json>"
  fluent-bit.config.outputs.http.tls.enabled: "true"
  fluent-bit.config.outputs.http.tls.verify : "false"
```

> **NOTE:** This configuration can also be passed using the new `additional` keyword. `additional` keywords exist also for inputs, filters, and parsers.

These are the same overrides passed using the `additional` keyword:

```yaml
apiVersion: v1
kind: ConfigMap
metadata:
  name: logging-overrides
  namespace: kyma-installer
  labels:
    installer: overrides
    component: logging
    kyma-project.io/installation: ""
data:
  fluent-bit.config.outputs.additional: |
      [OUTPUT]
          Name                        http
          Match                       *
          Host                        <Fluentd-endpoint from service key json>
          Port                        443
          HTTP_User                   <Fluentd-username from service key json>
          HTTP_Passwd                 <Fluentd-password from service key json>
          tls                         On
          tls.verify                  false
```

Additionally, we provide a way to keep the sensitive information - such as credentials for an output plugin - to be deployed inside a Secret instead of ending up in a ConfigMap on the cluster. You can pass the secret values as key/value pairs [here](https://github.com/kyma-project/kyma/blob/master/resources/logging/charts/fluent-bit/values.yaml#L135) and they will be populated to the Fluent Bit Pods as environment variables mounted from a Secret. Then, you can use the environment variable in the Fluent Bit configuration. We strongly recommend moving all the sensitive information in your configuration to this new field as it is kept more secure in a Secret.

We have also included many native Fluent Bit [parsers](https://github.com/kyma-project/kyma/blob/master/resources/logging/charts/fluent-bit/templates/kyma-additions/_parsers.tpl). You can use the parsers by specifying a [parser filter](https://docs.fluentbit.io/manual/pipeline/filters/parser) for your workload or by annotating the Pods as explained in the [Fluent Bit documentation](https://docs.fluentbit.io/manual/pipeline/filters/kubernetes#suggest-a-parser). 
